(function(factory){"use strict";if(typeof define==="function"&&define.amd){define(factory);}
else if(typeof module!="undefined"&&typeof module.exports!="undefined"){module.exports=factory();}
else if(typeof Package!=="undefined"){Sortable=factory();}
else{window["Sortable"]=factory();}})(function(){"use strict";var dragEl,parentEl,ghostEl,cloneEl,rootEl,nextEl,scrollEl,scrollParentEl,lastEl,lastCSS,lastParentCSS,oldIndex,newIndex,activeGroup,autoScroll={},tapEvt,touchEvt,moved,RSPACE=/\s+/g,expando='Sortable'+(new Date).getTime(),win=window,document=win.document,parseInt=win.parseInt,supportDraggable=!!('draggable'in document.createElement('div')),supportCssPointerEvents=(function(el){el=document.createElement('x');el.style.cssText='pointer-events:auto';return el.style.pointerEvents==='auto';})(),_silent=false,abs=Math.abs,slice=[].slice,touchDragOverListeners=[],_autoScroll=_throttle(function(evt,options,rootEl){if(rootEl&&options.scroll){var el,rect,sens=options.scrollSensitivity,speed=options.scrollSpeed,x=evt.clientX,y=evt.clientY,winWidth=window.innerWidth,winHeight=window.innerHeight,vx,vy;if(scrollParentEl!==rootEl){scrollEl=options.scroll;scrollParentEl=rootEl;if(scrollEl===true){scrollEl=rootEl;do{if((scrollEl.offsetWidth<scrollEl.scrollWidth)||(scrollEl.offsetHeight<scrollEl.scrollHeight)){break;}}while(scrollEl=scrollEl.parentNode);}}
if(scrollEl){el=scrollEl;rect=scrollEl.getBoundingClientRect();vx=(abs(rect.right-x)<=sens)-(abs(rect.left-x)<=sens);vy=(abs(rect.bottom-y)<=sens)-(abs(rect.top-y)<=sens);}
if(!(vx||vy)){vx=(winWidth-x<=sens)-(x<=sens);vy=(winHeight-y<=sens)-(y<=sens);(vx||vy)&&(el=win);}
if(autoScroll.vx!==vx||autoScroll.vy!==vy||autoScroll.el!==el){autoScroll.el=el;autoScroll.vx=vx;autoScroll.vy=vy;clearInterval(autoScroll.pid);if(el){autoScroll.pid=setInterval(function(){if(el===win){win.scrollTo(win.pageXOffset+vx*speed,win.pageYOffset+vy*speed);}else{vy&&(el.scrollTop+=vy*speed);vx&&(el.scrollLeft+=vx*speed);}},24);}}}},30),_prepareGroup=function(options){var group=options.group;if(!group||typeof group!='object'){group=options.group={name:group};}
['pull','put'].forEach(function(key){if(!(key in group)){group[key]=true;}});options.groups=' '+group.name+(group.put.join?' '+group.put.join(' '):'')+' ';};function Sortable(el,options){if(!(el&&el.nodeType&&el.nodeType===1)){throw'Sortable: `el` must be HTMLElement, and not '+{}.toString.call(el);}
this.el=el;this.options=options=_extend({},options);el[expando]=this;var defaults={group:Math.random(),sort:true,disabled:false,store:null,handle:null,scroll:true,scrollSensitivity:30,scrollSpeed:10,draggable:/[uo]l/i.test(el.nodeName)?'li':'>*',ghostClass:'sortable-ghost',chosenClass:'sortable-chosen',ignore:'a, img',filter:null,animation:0,setData:function(dataTransfer,dragEl){dataTransfer.setData('Text',dragEl.textContent);},dropBubble:false,dragoverBubble:false,dataIdAttr:'data-id',delay:0,forceFallback:false,fallbackClass:'sortable-fallback',fallbackOnBody:false};for(var name in defaults){!(name in options)&&(options[name]=defaults[name]);}
_prepareGroup(options);for(var fn in this){if(fn.charAt(0)==='_'){this[fn]=this[fn].bind(this);}}
this.nativeDraggable=options.forceFallback?false:supportDraggable;_on(el,'mousedown',this._onTapStart);_on(el,'touchstart',this._onTapStart);if(this.nativeDraggable){_on(el,'dragover',this);_on(el,'dragenter',this);}
touchDragOverListeners.push(this._onDragOver);options.store&&this.sort(options.store.get(this));}
Sortable.prototype={constructor:Sortable,_onTapStart:function(evt){var _this=this,el=this.el,options=this.options,type=evt.type,touch=evt.touches&&evt.touches[0],target=(touch||evt).target,originalTarget=target,filter=options.filter;if(type==='mousedown'&&evt.button!==0||options.disabled){return;}
target=_closest(target,options.draggable,el);if(!target){return;}
oldIndex=_index(target);if(typeof filter==='function'){if(filter.call(this,evt,target,this)){_dispatchEvent(_this,originalTarget,'filter',target,el,oldIndex);evt.preventDefault();return;}}
else if(filter){filter=filter.split(',').some(function(criteria){criteria=_closest(originalTarget,criteria.trim(),el);if(criteria){_dispatchEvent(_this,criteria,'filter',target,el,oldIndex);return true;}});if(filter){evt.preventDefault();return;}}
if(options.handle&&!_closest(originalTarget,options.handle,el)){return;}
this._prepareDragStart(evt,touch,target);},_prepareDragStart:function(evt,touch,target){var _this=this,el=_this.el,options=_this.options,ownerDocument=el.ownerDocument,dragStartFn;if(target&&!dragEl&&(target.parentNode===el)){tapEvt=evt;rootEl=el;dragEl=target;parentEl=dragEl.parentNode;nextEl=dragEl.nextSibling;activeGroup=options.group;dragStartFn=function(){_this._disableDelayedDrag();dragEl.draggable=true;_toggleClass(dragEl,_this.options.chosenClass,true);_this._triggerDragStart(touch);};options.ignore.split(',').forEach(function(criteria){_find(dragEl,criteria.trim(),_disableDraggable);});_on(ownerDocument,'mouseup',_this._onDrop);_on(ownerDocument,'touchend',_this._onDrop);_on(ownerDocument,'touchcancel',_this._onDrop);if(options.delay){_on(ownerDocument,'mouseup',_this._disableDelayedDrag);_on(ownerDocument,'touchend',_this._disableDelayedDrag);_on(ownerDocument,'touchcancel',_this._disableDelayedDrag);_on(ownerDocument,'mousemove',_this._disableDelayedDrag);_on(ownerDocument,'touchmove',_this._disableDelayedDrag);_this._dragStartTimer=setTimeout(dragStartFn,options.delay);}else{dragStartFn();}}},_disableDelayedDrag:function(){var ownerDocument=this.el.ownerDocument;clearTimeout(this._dragStartTimer);_off(ownerDocument,'mouseup',this._disableDelayedDrag);_off(ownerDocument,'touchend',this._disableDelayedDrag);_off(ownerDocument,'touchcancel',this._disableDelayedDrag);_off(ownerDocument,'mousemove',this._disableDelayedDrag);_off(ownerDocument,'touchmove',this._disableDelayedDrag);},_triggerDragStart:function(touch){if(touch){tapEvt={target:dragEl,clientX:touch.clientX,clientY:touch.clientY};this._onDragStart(tapEvt,'touch');}
else if(!this.nativeDraggable){this._onDragStart(tapEvt,true);}
else{_on(dragEl,'dragend',this);_on(rootEl,'dragstart',this._onDragStart);}
try{if(document.selection){document.selection.empty();}else{window.getSelection().removeAllRanges();}}catch(err){}},_dragStarted:function(){if(rootEl&&dragEl){_toggleClass(dragEl,this.options.ghostClass,true);Sortable.active=this;_dispatchEvent(this,rootEl,'start',dragEl,rootEl,oldIndex);}},_emulateDragOver:function(){if(touchEvt){if(this._lastX===touchEvt.clientX&&this._lastY===touchEvt.clientY){return;}
this._lastX=touchEvt.clientX;this._lastY=touchEvt.clientY;if(!supportCssPointerEvents){_css(ghostEl,'display','none');}
var target=document.elementFromPoint(touchEvt.clientX,touchEvt.clientY),parent=target,groupName=' '+this.options.group.name+'',i=touchDragOverListeners.length;if(parent){do{if(parent[expando]&&parent[expando].options.groups.indexOf(groupName)>-1){while(i--){touchDragOverListeners[i]({clientX:touchEvt.clientX,clientY:touchEvt.clientY,target:target,rootEl:parent});}
break;}
target=parent;}
while(parent=parent.parentNode);}
if(!supportCssPointerEvents){_css(ghostEl,'display','');}}},_onTouchMove:function(evt){if(tapEvt){if(!Sortable.active){this._dragStarted();}
this._appendGhost();var touch=evt.touches?evt.touches[0]:evt,dx=touch.clientX-tapEvt.clientX,dy=touch.clientY-tapEvt.clientY,translate3d=evt.touches?'translate3d('+dx+'px,'+dy+'px,0)':'translate('+dx+'px,'+dy+'px)';moved=true;touchEvt=touch;_css(ghostEl,'webkitTransform',translate3d);_css(ghostEl,'mozTransform',translate3d);_css(ghostEl,'msTransform',translate3d);_css(ghostEl,'transform',translate3d);evt.preventDefault();}},_appendGhost:function(){if(!ghostEl){var rect=dragEl.getBoundingClientRect(),css=_css(dragEl),options=this.options,ghostRect;ghostEl=dragEl.cloneNode(true);_toggleClass(ghostEl,options.ghostClass,false);_toggleClass(ghostEl,options.fallbackClass,true);_css(ghostEl,'top',rect.top-parseInt(css.marginTop,10));_css(ghostEl,'left',rect.left-parseInt(css.marginLeft,10));_css(ghostEl,'width',rect.width);_css(ghostEl,'height',rect.height);_css(ghostEl,'opacity','0.8');_css(ghostEl,'position','fixed');_css(ghostEl,'zIndex','100000');_css(ghostEl,'pointerEvents','none');options.fallbackOnBody&&document.body.appendChild(ghostEl)||rootEl.appendChild(ghostEl);ghostRect=ghostEl.getBoundingClientRect();_css(ghostEl,'width',rect.width*2-ghostRect.width);_css(ghostEl,'height',rect.height*2-ghostRect.height);}},_onDragStart:function(evt,useFallback){var dataTransfer=evt.dataTransfer,options=this.options;this._offUpEvents();if(activeGroup.pull=='clone'){cloneEl=dragEl.cloneNode(true);_css(cloneEl,'display','none');rootEl.insertBefore(cloneEl,dragEl);}
if(useFallback){if(useFallback==='touch'){_on(document,'touchmove',this._onTouchMove);_on(document,'touchend',this._onDrop);_on(document,'touchcancel',this._onDrop);}else{_on(document,'mousemove',this._onTouchMove);_on(document,'mouseup',this._onDrop);}
this._loopId=setInterval(this._emulateDragOver,50);}
else{if(dataTransfer){dataTransfer.effectAllowed='move';options.setData&&options.setData.call(this,dataTransfer,dragEl);}
_on(document,'drop',this);setTimeout(this._dragStarted,0);}},_onDragOver:function(evt){var el=this.el,target,dragRect,revert,options=this.options,group=options.group,groupPut=group.put,isOwner=(activeGroup===group),canSort=options.sort;if(evt.preventDefault!==void 0){evt.preventDefault();!options.dragoverBubble&&evt.stopPropagation();}
moved=true;if(activeGroup&&!options.disabled&&(isOwner?canSort||(revert=!rootEl.contains(dragEl)):activeGroup.pull&&groupPut&&((activeGroup.name===group.name)||(groupPut.indexOf&&~groupPut.indexOf(activeGroup.name))))&&(evt.rootEl===void 0||evt.rootEl===this.el)){_autoScroll(evt,options,this.el);if(_silent){return;}
target=_closest(evt.target,options.draggable,el);dragRect=dragEl.getBoundingClientRect();if(revert){_cloneHide(true);if(cloneEl||nextEl){rootEl.insertBefore(dragEl,cloneEl||nextEl);}
else if(!canSort){rootEl.appendChild(dragEl);}
return;}
if((el.children.length===0)||(el.children[0]===ghostEl)||(el===evt.target)&&(target=_ghostIsLast(el,evt))){if(target){if(target.animated){return;}
targetRect=target.getBoundingClientRect();}
_cloneHide(isOwner);if(_onMove(rootEl,el,dragEl,dragRect,target,targetRect)!==false){if(!dragEl.contains(el)){el.appendChild(dragEl);parentEl=el;}
this._animate(dragRect,dragEl);target&&this._animate(targetRect,target);}}
else if(target&&!target.animated&&target!==dragEl&&(target.parentNode[expando]!==void 0)){if(lastEl!==target){lastEl=target;lastCSS=_css(target);lastParentCSS=_css(target.parentNode);}
var targetRect=target.getBoundingClientRect(),width=targetRect.right-targetRect.left,height=targetRect.bottom-targetRect.top,floating=/left|right|inline/.test(lastCSS.cssFloat+lastCSS.display)||(lastParentCSS.display=='flex'&&lastParentCSS['flex-direction'].indexOf('row')===0),isWide=(target.offsetWidth>dragEl.offsetWidth),isLong=(target.offsetHeight>dragEl.offsetHeight),halfway=(floating?(evt.clientX-targetRect.left)/width:(evt.clientY-targetRect.top)/height)>0.5,nextSibling=target.nextElementSibling,moveVector=_onMove(rootEl,el,dragEl,dragRect,target,targetRect),after;if(moveVector!==false){_silent=true;setTimeout(_unsilent,30);_cloneHide(isOwner);if(moveVector===1||moveVector===-1){after=(moveVector===1);}
else if(floating){var elTop=dragEl.offsetTop,tgTop=target.offsetTop;if(elTop===tgTop){after=(target.previousElementSibling===dragEl)&&!isWide||halfway&&isWide;}else{after=tgTop>elTop;}}else{after=(nextSibling!==dragEl)&&!isLong||halfway&&isLong;}
if(!dragEl.contains(el)){if(after&&!nextSibling){el.appendChild(dragEl);}else{target.parentNode.insertBefore(dragEl,after?nextSibling:target);}}
parentEl=dragEl.parentNode;this._animate(dragRect,dragEl);this._animate(targetRect,target);}}}},_animate:function(prevRect,target){var ms=this.options.animation;if(ms){var currentRect=target.getBoundingClientRect();_css(target,'transition','none');_css(target,'transform','translate3d('
+(prevRect.left-currentRect.left)+'px,'
+(prevRect.top-currentRect.top)+'px,0)');target.offsetWidth;_css(target,'transition','all '+ms+'ms');_css(target,'transform','translate3d(0,0,0)');clearTimeout(target.animated);target.animated=setTimeout(function(){_css(target,'transition','');_css(target,'transform','');target.animated=false;},ms);}},_offUpEvents:function(){var ownerDocument=this.el.ownerDocument;_off(document,'touchmove',this._onTouchMove);_off(ownerDocument,'mouseup',this._onDrop);_off(ownerDocument,'touchend',this._onDrop);_off(ownerDocument,'touchcancel',this._onDrop);},_onDrop:function(evt){var el=this.el,options=this.options;clearInterval(this._loopId);clearInterval(autoScroll.pid);clearTimeout(this._dragStartTimer);_off(document,'mousemove',this._onTouchMove);if(this.nativeDraggable){_off(document,'drop',this);_off(el,'dragstart',this._onDragStart);}
this._offUpEvents();if(evt){if(moved){evt.preventDefault();!options.dropBubble&&evt.stopPropagation();}
ghostEl&&ghostEl.parentNode.removeChild(ghostEl);if(dragEl){if(this.nativeDraggable){_off(dragEl,'dragend',this);}
_disableDraggable(dragEl);_toggleClass(dragEl,this.options.ghostClass,false);_toggleClass(dragEl,this.options.chosenClass,false);if(rootEl!==parentEl){newIndex=_index(dragEl);if(newIndex>=0){_dispatchEvent(null,parentEl,'sort',dragEl,rootEl,oldIndex,newIndex);_dispatchEvent(this,rootEl,'sort',dragEl,rootEl,oldIndex,newIndex);_dispatchEvent(null,parentEl,'add',dragEl,rootEl,oldIndex,newIndex);_dispatchEvent(this,rootEl,'remove',dragEl,rootEl,oldIndex,newIndex);}}
else{cloneEl&&cloneEl.parentNode.removeChild(cloneEl);if(dragEl.nextSibling!==nextEl){newIndex=_index(dragEl);if(newIndex>=0){_dispatchEvent(this,rootEl,'update',dragEl,rootEl,oldIndex,newIndex);_dispatchEvent(this,rootEl,'sort',dragEl,rootEl,oldIndex,newIndex);}}}
if(Sortable.active){if(newIndex===null||newIndex===-1){newIndex=oldIndex;}
_dispatchEvent(this,rootEl,'end',dragEl,rootEl,oldIndex,newIndex);this.save();}}
rootEl=dragEl=parentEl=ghostEl=nextEl=cloneEl=scrollEl=scrollParentEl=tapEvt=touchEvt=moved=newIndex=lastEl=lastCSS=activeGroup=Sortable.active=null;}},handleEvent:function(evt){var type=evt.type;if(type==='dragover'||type==='dragenter'){if(dragEl){this._onDragOver(evt);_globalDragOver(evt);}}
else if(type==='drop'||type==='dragend'){this._onDrop(evt);}},toArray:function(){var order=[],el,children=this.el.children,i=0,n=children.length,options=this.options;for(;i<n;i++){el=children[i];if(_closest(el,options.draggable,this.el)){order.push(el.getAttribute(options.dataIdAttr)||_generateId(el));}}
return order;},sort:function(order){var items={},rootEl=this.el;this.toArray().forEach(function(id,i){var el=rootEl.children[i];if(_closest(el,this.options.draggable,rootEl)){items[id]=el;}},this);order.forEach(function(id){if(items[id]){rootEl.removeChild(items[id]);rootEl.appendChild(items[id]);}});},save:function(){var store=this.options.store;store&&store.set(this);},closest:function(el,selector){return _closest(el,selector||this.options.draggable,this.el);},option:function(name,value){var options=this.options;if(value===void 0){return options[name];}else{options[name]=value;if(name==='group'){_prepareGroup(options);}}},destroy:function(){var el=this.el;el[expando]=null;_off(el,'mousedown',this._onTapStart);_off(el,'touchstart',this._onTapStart);if(this.nativeDraggable){_off(el,'dragover',this);_off(el,'dragenter',this);}
Array.prototype.forEach.call(el.querySelectorAll('[draggable]'),function(el){el.removeAttribute('draggable');});touchDragOverListeners.splice(touchDragOverListeners.indexOf(this._onDragOver),1);this._onDrop();this.el=el=null;}};function _cloneHide(state){if(cloneEl&&(cloneEl.state!==state)){_css(cloneEl,'display',state?'none':'');!state&&cloneEl.state&&rootEl.insertBefore(cloneEl,dragEl);cloneEl.state=state;}}
function _closest(el,selector,ctx){if(el){ctx=ctx||document;selector=selector.split('.');var tag=selector.shift().toUpperCase(),re=new RegExp('\\s('+selector.join('|')+')(?=\\s)','g');do{if((tag==='>*'&&el.parentNode===ctx)||((tag===''||el.nodeName.toUpperCase()==tag)&&(!selector.length||((' '+el.className+' ').match(re)||[]).length==selector.length))){return el;}}
while(el!==ctx&&(el=el.parentNode));}
return null;}
function _globalDragOver(evt){if(evt.dataTransfer){evt.dataTransfer.dropEffect='move';}
evt.preventDefault();}
function _on(el,event,fn){el.addEventListener(event,fn,false);}
function _off(el,event,fn){el.removeEventListener(event,fn,false);}
function _toggleClass(el,name,state){if(el){if(el.classList){el.classList[state?'add':'remove'](name);}
else{var className=(' '+el.className+' ').replace(RSPACE,' ').replace(' '+name+' ',' ');el.className=(className+(state?' '+name:'')).replace(RSPACE,' ');}}}
function _css(el,prop,val){var style=el&&el.style;if(style){if(val===void 0){if(document.defaultView&&document.defaultView.getComputedStyle){val=document.defaultView.getComputedStyle(el,'');}
else if(el.currentStyle){val=el.currentStyle;}
return prop===void 0?val:val[prop];}
else{if(!(prop in style)){prop='-webkit-'+prop;}
style[prop]=val+(typeof val==='string'?'':'px');}}}
function _find(ctx,tagName,iterator){if(ctx){var list=ctx.getElementsByTagName(tagName),i=0,n=list.length;if(iterator){for(;i<n;i++){iterator(list[i],i);}}
return list;}
return[];}
function _dispatchEvent(sortable,rootEl,name,targetEl,fromEl,startIndex,newIndex){var evt=document.createEvent('Event'),options=(sortable||rootEl[expando]).options,onName='on'+name.charAt(0).toUpperCase()+name.substr(1);evt.initEvent(name,true,true);evt.to=rootEl;evt.from=fromEl||rootEl;evt.item=targetEl||rootEl;evt.clone=cloneEl;evt.oldIndex=startIndex;evt.newIndex=newIndex;rootEl.dispatchEvent(evt);if(options[onName]){options[onName].call(sortable,evt);}}
function _onMove(fromEl,toEl,dragEl,dragRect,targetEl,targetRect){var evt,sortable=fromEl[expando],onMoveFn=sortable.options.onMove,retVal;evt=document.createEvent('Event');evt.initEvent('move',true,true);evt.to=toEl;evt.from=fromEl;evt.dragged=dragEl;evt.draggedRect=dragRect;evt.related=targetEl||toEl;evt.relatedRect=targetRect||toEl.getBoundingClientRect();fromEl.dispatchEvent(evt);if(onMoveFn){retVal=onMoveFn.call(sortable,evt);}
return retVal;}
function _disableDraggable(el){el.draggable=false;}
function _unsilent(){_silent=false;}
function _ghostIsLast(el,evt){var lastEl=el.lastElementChild,rect=lastEl.getBoundingClientRect();return((evt.clientY-(rect.top+rect.height)>5)||(evt.clientX-(rect.right+rect.width)>5))&&lastEl;}
function _generateId(el){var str=el.tagName+el.className+el.src+el.href+el.textContent,i=str.length,sum=0;while(i--){sum+=str.charCodeAt(i);}
return sum.toString(36);}
function _index(el){var index=0;if(!el||!el.parentNode){return-1;}
while(el&&(el=el.previousElementSibling)){if(el.nodeName.toUpperCase()!=='TEMPLATE'){index++;}}
return index;}
function _throttle(callback,ms){var args,_this;return function(){if(args===void 0){args=arguments;_this=this;setTimeout(function(){if(args.length===1){callback.call(_this,args[0]);}else{callback.apply(_this,args);}
args=void 0;},ms);}};}
function _extend(dst,src){if(dst&&src){for(var key in src){if(src.hasOwnProperty(key)){dst[key]=src[key];}}}
return dst;}
Sortable.utils={on:_on,off:_off,css:_css,find:_find,is:function(el,selector){return!!_closest(el,selector,el);},extend:_extend,throttle:_throttle,closest:_closest,toggleClass:_toggleClass,index:_index};Sortable.create=function(el,options){return new Sortable(el,options);};Sortable.version='1.4.1';return Sortable;});var on_move_element=function(list,element,new_index,old_index){var siblings=$(list).children('li');if(siblings.length<2){return;}
var target=new_index===0?siblings[1]:siblings[new_index-1];var direction=new_index===0?'above':'below';var url=decodeURIComponent($(list).data('sortable-url')).replace('{subject_id}',$(element).data('sortable-id')).replace('{target_id}',$(target).data('sortable-id')).replace('{direction}',direction);$.ajax({type:"PUT",url:url}).done(function(){$(element).addClass('flash').addClass('success');}).fail(function(){undo_move_element(list,element,new_index,old_index);$(element).addClass('flash').addClass('failure');}).always(function(){setTimeout(function(){$(element).removeClass('flash').removeClass('success').removeClass('failure');},1000);});};var undo_move_element=function(list,element,new_index,old_index){var siblings=$(list).children('li');if(old_index===0){$(element).insertBefore($(siblings[0]));}else{if(old_index<=new_index){$(element).insertAfter($(siblings[old_index-1]));}else{$(element).insertAfter($(siblings[old_index]));}}};var setup_sortable_list=function(list_element){var list=$(list_element);var start=null;var sortable=Sortable.create(list_element,{onStart:function(event){if($(event.element).parent().hasClass('children')){return;}
var last_element=list.find('> li').last();if(last_element.find('.children').length!==0){list.append($('<li class="empty">&nbsp;</li>'));}
start=(new Date()).getTime();},onEnd:function(event){list.find('> .empty').remove();var new_index=event.newIndex;if(new_index>=list.find('> li').length){new_index=list.find('> li').length-1;}
if(new_index!=event.oldIndex){if(((new Date()).getTime()-start)<=200){undo_move_element(list_element,event.item,new_index,event.oldIndex);}else{on_move_element(list_element,event.item,new_index,event.oldIndex);}}}});list.children('li').each(function(){this.addEventListener('dragstart',function(event){$(event.target).addClass('dragging');});});};(function($){$(document).ready(function(){$('ul[data-sortable]').each(function(){setup_sortable_list(this);});});})(jQuery);